extract_address extract addresses using get_address.
extract_address(n = 100, postcode = NA)A number.
A string.
The output is n addresses in the form of a data framework
with n observations with 5 variables:
postcode of the UK address,
country,
primary_care_trust,
longitude of the address,
latitude of the address.
If postcode is given, the return addresses are addresses
having the same outward postcode